Disable Dex2oatSwapUseTest.CheckSwapUsage for x86_64

Dex2oatSwapUseTest.CheckSwapUsage disabled for all targets
was changed to be disabled only for x86. However the test
frequently fails on x86_64 as well.

This CL disables the test for x86_64.

Test: test.py --host --gtest
Test: dex2oat_test
Test: run-gtests.sh
Bug: 29259363

Change-Id: I88a8bf735d2702c914ba952bdcc2431a85dbf761
diff --git a/runtime/common_runtime_test.h b/runtime/common_runtime_test.h
index 61c8847..c87d317 100644
--- a/runtime/common_runtime_test.h
+++ b/runtime/common_runtime_test.h
@@ -257,6 +257,12 @@
     return; \
   }
 
+#define TEST_DISABLED_FOR_X86_64() \
+  if (kRuntimeISA == InstructionSet::kX86_64) { \
+    printf("WARNING: TEST DISABLED FOR X86_64\n"); \
+    return; \
+  }
+
 #define TEST_DISABLED_FOR_STRING_COMPRESSION() \
   if (mirror::kUseStringCompression) { \
     printf("WARNING: TEST DISABLED FOR STRING COMPRESSION\n"); \
diff --git a/dex2oat/dex2oat_test.cc b/dex2oat/dex2oat_test.cc
index 7ff9b73..2d2b958 100644
--- a/dex2oat/dex2oat_test.cc
+++ b/dex2oat/dex2oat_test.cc
@@ -458,9 +458,10 @@
   TEST_DISABLED_FOR_MEMORY_TOOL();
 
   // The `native_alloc_2_ >= native_alloc_1_` assertion below may not
   // hold true on some x86 systems; disable this test while we
   // investigate (b/29259363).
   TEST_DISABLED_FOR_X86();
+  TEST_DISABLED_FOR_X86_64();
 
   RunTest(/*use_fd=*/ false,
           /*expect_use=*/ false);
@@ -458,9 +458,10 @@
 
   // The `native_alloc_2_ >= native_alloc_1_` assertion below may not
-  // hold true on some x86 systems; disable this test while we
+  // hold true on some x86 or x86_64 systems; disable this test while we
   // investigate (b/29259363).
   TEST_DISABLED_FOR_X86();